@@ -103,7 +103,7 @@ impl BitcoinDB {
     /// `get_hash_from_height()`, will necessarily return valid
     /// data, as long as height is smaller than `get_max_height()`.
     ///
-    fn get_max_height(&self) -> usize {
+    pub fn get_max_height(&self) -> usize {
         self.block_index.records.len()
     }
 
